@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import pytest
 
 from textual.app import App, ComposeResult
@@ -24,6 +26,7 @@ async def test_tabbed_content_switch_via_ui():
         tabbed_content = app.query_one(TabbedContent)
         # Check first tab
         assert tabbed_content.active == "foo"
+        assert tabbed_content.active_pane.id == "foo"
         await pilot.pause()
         assert app.query_one("#foo-label").region
         assert not app.query_one("#bar-label").region
@@ -32,6 +35,7 @@ async def test_tabbed_content_switch_via_ui():
         # Click second tab
         await pilot.click(f"Tab#{ContentTab.add_prefix('bar')}")
         assert tabbed_content.active == "bar"
+        assert tabbed_content.active_pane.id == "bar"
         await pilot.pause()
         assert not app.query_one("#foo-label").region
         assert app.query_one("#bar-label").region
@@ -40,6 +44,7 @@ async def test_tabbed_content_switch_via_ui():
         # Click third tab
         await pilot.click(f"Tab#{ContentTab.add_prefix('baz')}")
         assert tabbed_content.active == "baz"
+        assert tabbed_content.active_pane.id == "baz"
         await pilot.pause()
         assert not app.query_one("#foo-label").region
         assert not app.query_one("#bar-label").region
@@ -134,13 +139,12 @@ async def test_tabbed_content_initial():
 
 async def test_tabbed_content_messages():
     class TabbedApp(App):
-        message = None
+        activation_history: list[Tab] = []
 
         def compose(self) -> ComposeResult:
-            with TabbedContent(initial="bar"):
+            with TabbedContent():
                 with TabPane("foo", id="foo"):
                     yield Label("Foo", id="foo-label")
-
                 with TabPane("bar", id="bar"):
                     yield Label("Bar", id="bar-label")
                 with TabPane("baz", id="baz"):
@@ -149,15 +153,19 @@ async def test_tabbed_content_messages():
         def on_tabbed_content_tab_activated(
             self, event: TabbedContent.TabActivated
         ) -> None:
-            self.message = event
+            self.activation_history.append(event.tab)
 
     app = TabbedApp()
     async with app.run_test() as pilot:
         tabbed_content = app.query_one(TabbedContent)
         tabbed_content.active = "bar"
         await pilot.pause()
-        assert isinstance(app.message, TabbedContent.TabActivated)
-        assert app.message.tab.label.plain == "bar"
+        assert app.activation_history == [
+            # foo was originally activated.
+            app.query_one(TabbedContent).get_tab("foo"),
+            # then we did bar "by hand"
+            app.query_one(TabbedContent).get_tab("bar"),
+        ]
 
 
 async def test_tabbed_content_add_later_from_empty():
